<?php

namespace Joolano\Joolano\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Joolano\Joolano\Http\Requests\PricingLogicRequest;
use Joolano\Joolano\Interfaces\PricingLogicRepositoryInterface;
use Joolano\Joolano\Models\PricingLogic;

/**
 * Resource controller class for pricing_logic.
 */
class PricingLogicResourceController extends BaseController
{

    /**
     * Initialize pricing_logic resource controller.
     *
     * @param type PricingLogicRepositoryInterface $pricing_logic
     *
     * @return null
     */
    public function __construct(PricingLogicRepositoryInterface $pricing_logic)
    {
        parent::__construct();
        $this->repository = $pricing_logic;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Joolano\Joolano\Repositories\Criteria\PricingLogicResourceCriteria::class);
    }

    /**
     * Display a list of pricing_logic.
     *
     * @return Response
     */
    public function index(PricingLogicRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Joolano\Joolano\Repositories\Presenter\PricingLogicPresenter::class)
                ->$function();
        }

        $pricing_logics = $this->repository->paginate();

        return $this->response->title(trans('joolano::pricing_logic.names'))
            ->view('joolano::pricing_logic.index', true)
            ->data(compact('pricing_logics', 'view'))
            ->output();
    }

    /**
     * Display pricing_logic.
     *
     * @param Request $request
     * @param Model   $pricing_logic
     *
     * @return Response
     */
    public function show(PricingLogicRequest $request, PricingLogic $pricing_logic)
    {

        if ($pricing_logic->exists) {
            $view = 'joolano::pricing_logic.show';
        } else {
            $view = 'joolano::pricing_logic.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('joolano::pricing_logic.name'))
            ->data(compact('pricing_logic'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new pricing_logic.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PricingLogicRequest $request)
    {

        $pricing_logic = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('joolano::pricing_logic.name')) 
            ->view('joolano::pricing_logic.create', true) 
            ->data(compact('pricing_logic'))
            ->output();
    }

    /**
     * Create new pricing_logic.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PricingLogicRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $pricing_logic                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('joolano::pricing_logic.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('joolano/pricing_logic/' . $pricing_logic->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/joolano/pricing_logic'))
                ->redirect();
        }

    }

    /**
     * Show pricing_logic for editing.
     *
     * @param Request $request
     * @param Model   $pricing_logic
     *
     * @return Response
     */
    public function edit(PricingLogicRequest $request, PricingLogic $pricing_logic)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('joolano::pricing_logic.name'))
            ->view('joolano::pricing_logic.edit', true)
            ->data(compact('pricing_logic'))
            ->output();
    }

    /**
     * Update the pricing_logic.
     *
     * @param Request $request
     * @param Model   $pricing_logic
     *
     * @return Response
     */
    public function update(PricingLogicRequest $request, PricingLogic $pricing_logic)
    {
        try {
            $attributes = $request->all();

            $pricing_logic->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('joolano::pricing_logic.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('joolano/pricing_logic/' . $pricing_logic->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('joolano/pricing_logic/' . $pricing_logic->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the pricing_logic.
     *
     * @param Model   $pricing_logic
     *
     * @return Response
     */
    public function destroy(PricingLogicRequest $request, PricingLogic $pricing_logic)
    {
        try {

            $pricing_logic->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('joolano::pricing_logic.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('joolano/pricing_logic/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('joolano/pricing_logic/' . $pricing_logic->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple pricing_logic.
     *
     * @param Model   $pricing_logic
     *
     * @return Response
     */
    public function delete(PricingLogicRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('joolano::pricing_logic.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('joolano/pricing_logic'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/joolano/pricing_logic'))
                ->redirect();
        }

    }

    /**
     * Restore deleted pricing_logics.
     *
     * @param Model   $pricing_logic
     *
     * @return Response
     */
    public function restore(PricingLogicRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('joolano::pricing_logic.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/joolano/pricing_logic'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/joolano/pricing_logic/'))
                ->redirect();
        }

    }

}
