<?php

namespace Joolano\Joolano\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Joolano\Joolano\Http\Requests\PricingLogicRequest;
use Joolano\Joolano\Models\PricingLogic;

/**
 * Admin web controller class.
 */
class PricingLogicWorkflowController extends BaseController
{

    /**
     * Workflow controller function for pricing_logic.
     *
     * @param Model   $pricing_logic
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PricingLogicRequest $request, PricingLogic $pricing_logic, $step)
    {

        try {

            $pricing_logic->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('joolano::pricing_logic.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/pricing_logic/pricing_logic/' . $pricing_logic->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/pricing_logic/pricing_logic/' . $pricing_logic->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for pricing_logic.
     *
     * @param Model   $pricing_logic
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(PricingLogic $pricing_logic, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $pricing_logic->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('joolano::pricing_logic.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('joolano::admin.pricing_logic.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('joolano::admin.pricing_logic.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('joolano::admin.pricing_logic.message', $data)->render();

        }

    }
}
