<?php

namespace Joolano\Joolano\Policies;

use Litepie\User\Contracts\UserPolicy;
use Joolano\Joolano\Models\PricingLogic;

class PricingLogicPolicy
{

    /**
     * Determine if the given user can view the pricing_logic.
     *
     * @param UserPolicy $user
     * @param PricingLogic $pricing_logic
     *
     * @return bool
     */
    public function view(UserPolicy $user, PricingLogic $pricing_logic)
    {
        if ($user->canDo('joolano.pricing_logic.view') && $user->isAdmin()) {
            return true;
        }

        return $pricing_logic->user_id == user_id() && $pricing_logic->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pricing_logic.
     *
     * @param UserPolicy $user
     * @param PricingLogic $pricing_logic
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('joolano.pricing_logic.create');
    }

    /**
     * Determine if the given user can update the given pricing_logic.
     *
     * @param UserPolicy $user
     * @param PricingLogic $pricing_logic
     *
     * @return bool
     */
    public function update(UserPolicy $user, PricingLogic $pricing_logic)
    {
        if ($user->canDo('joolano.pricing_logic.edit') && $user->isAdmin()) {
            return true;
        }

        return $pricing_logic->user_id == user_id() && $pricing_logic->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pricing_logic.
     *
     * @param UserPolicy $user
     * @param PricingLogic $pricing_logic
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PricingLogic $pricing_logic)
    {
        return $pricing_logic->user_id == user_id() && $pricing_logic->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pricing_logic.
     *
     * @param UserPolicy $user
     * @param PricingLogic $pricing_logic
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PricingLogic $pricing_logic)
    {
        if ($user->canDo('joolano.pricing_logic.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pricing_logic.
     *
     * @param UserPolicy $user
     * @param PricingLogic $pricing_logic
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PricingLogic $pricing_logic)
    {
        if ($user->canDo('joolano.pricing_logic.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
