<?php

namespace Joolano\Joolano\Policies;

use Litepie\User\Contracts\UserPolicy;
use Joolano\Joolano\Models\ServiceType;

class ServiceTypePolicy
{

    /**
     * Determine if the given user can view the service_type.
     *
     * @param UserPolicy $user
     * @param ServiceType $service_type
     *
     * @return bool
     */
    public function view(UserPolicy $user, ServiceType $service_type)
    {
        if ($user->canDo('joolano.service_type.view') && $user->isAdmin()) {
            return true;
        }

        return $service_type->user_id == user_id() && $service_type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a service_type.
     *
     * @param UserPolicy $user
     * @param ServiceType $service_type
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('joolano.service_type.create');
    }

    /**
     * Determine if the given user can update the given service_type.
     *
     * @param UserPolicy $user
     * @param ServiceType $service_type
     *
     * @return bool
     */
    public function update(UserPolicy $user, ServiceType $service_type)
    {
        if ($user->canDo('joolano.service_type.edit') && $user->isAdmin()) {
            return true;
        }

        return $service_type->user_id == user_id() && $service_type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given service_type.
     *
     * @param UserPolicy $user
     * @param ServiceType $service_type
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ServiceType $service_type)
    {
        return $service_type->user_id == user_id() && $service_type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given service_type.
     *
     * @param UserPolicy $user
     * @param ServiceType $service_type
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ServiceType $service_type)
    {
        if ($user->canDo('joolano.service_type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given service_type.
     *
     * @param UserPolicy $user
     * @param ServiceType $service_type
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ServiceType $service_type)
    {
        if ($user->canDo('joolano.service_type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
