<?php

namespace Joolano\Joolano\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Joolano\Joolano\Models\PricingLogic;

class PricingLogicAction
{
    /**
     * Perform the complete action.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return PricingLogic
     */
    public function complete(PricingLogic $pricing_logic)
    {
        try {
            $pricing_logic->status = 'complete';
            return $pricing_logic->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return PricingLogic
     */public function verify(PricingLogic $pricing_logic)
    {
        try {
            $pricing_logic->status = 'verify';
            return $pricing_logic->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return PricingLogic
     */public function approve(PricingLogic $pricing_logic)
    {
        try {
            $pricing_logic->status = 'approve';
            return $pricing_logic->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return PricingLogic
     */public function publish(PricingLogic $pricing_logic)
    {
        try {
            $pricing_logic->status = 'publish';
            return $pricing_logic->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return PricingLogic
     */
    public function archive(PricingLogic $pricing_logic)
    {
        try {
            $pricing_logic->status = 'archive';
            return $pricing_logic->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return PricingLogic
     */
    public function unpublish(PricingLogic $pricing_logic)
    {
        try {
            $pricing_logic->status = 'unpublish';
            return $pricing_logic->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
