<?php

namespace Joolano\Joolano\Workflow;

use Joolano\Joolano\Models\PricingLogic;
use Validator;

class PricingLogicValidator
{

    /**
     * Determine if the given pricing_logic is valid for complete status.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return bool / Validator
     */
    public function complete(PricingLogic $pricing_logic)
    {
        return Validator::make($pricing_logic->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given pricing_logic is valid for verify status.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return bool / Validator
     */
    public function verify(PricingLogic $pricing_logic)
    {
        return Validator::make($pricing_logic->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given pricing_logic is valid for approve status.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return bool / Validator
     */
    public function approve(PricingLogic $pricing_logic)
    {
        return Validator::make($pricing_logic->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given pricing_logic is valid for publish status.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return bool / Validator
     */
    public function publish(PricingLogic $pricing_logic)
    {
        return Validator::make($pricing_logic->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given pricing_logic is valid for archive status.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return bool / Validator
     */
    public function archive(PricingLogic $pricing_logic)
    {
        return Validator::make($pricing_logic->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given pricing_logic is valid for unpublish status.
     *
     * @param PricingLogic $pricing_logic
     *
     * @return bool / Validator
     */
    public function unpublish(PricingLogic $pricing_logic)
    {
        return Validator::make($pricing_logic->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
